/*
 * obierrno.h
 *
 *  Created on: 23 mai 2015
 *      Author: coissac
 */

#ifndef OBIERRNO_H_
#define OBIERRNO_H_

/**
 * @brief The declaration of the external variable `obi_errno`.
 *
 * `obi_errno` is an equivalent of `errno` for the system level error,
 * but for errors generated by the C layer of the OBITools framework.
 *
 * @todo We have to look into defining this variable as thread specific.
 */
extern int obi_errno;


/**
 * @brief Sets the global `obi_errno` variable with
 *        the specified `err` code
 *
 * This function is defined as a macro to reduce the risk
 * of increasing the problem generating the error by calling
 * a new function.
 *
 * @param err The error code as an integer value.
 *
 * @since May 2015
 * @author Eric Coissac (eric.coissac@metabarcoding.org)
 */
#define obi_set_errno(err) (obi_errno = (err))


/**
 * @defgroup OBIDMSErrors OBIDMS related error codes
 *
 * Error codes set in errno following an error related
 * to the manipulation of an OBIDMS.
 *
 * @{
 */
#define OBIDMS_EXIST_ERROR     		(1) 	/**< Trying to create an OBIDMS with a name
                                    		 *   that corresponds to an existing one
                                    		 */
#define OBIDMS_NOT_EXIST_ERROR 		(2) 	/**< Trying to open a non-existing OBIDMS
                                    		 */
#define OBIDMS_LONG_NAME_ERROR 		(3) 	/**< The specified OBIDMS name is too long
                                    		 */
#define OBIDMS_MEMORY_ERROR    		(4) 	/**< A memory error occurred during allocation while handling
											 *   an OBIDMS
                                    		 */
#define OBIDMS_UNKNOWN_ERROR   		(5) 	/**< Undetermined error while handling an OBIDMS
                                    		 */
#define OBIDMS_ACCESS_ERROR    		(6) 	/**< Permission error trying to access the database
                                    		 */

#define OBICOLDIR_EXIST_ERROR     	(7) 	/**< Trying to create an OBIDMS column directory with a name
                                    		 *   that corresponds to an existing one
                                    		 */
#define OBICOLDIR_NOT_EXIST_ERROR 	(8) 	/**< Trying to open a non-existing OBIDMS column directory
                                    		 */
#define OBICOLDIR_LONG_NAME_ERROR 	(9) 	/**< The specified OBIDMS column directory name is too long
                                    		 */
#define OBICOLDIR_MEMORY_ERROR    	(10) 	/**< A memory error occurred during allocation while handling
											 *	 an OBIDMS column directory
                                    	 	 */
#define OBICOLDIR_UNKNOWN_ERROR   	(11) 	/**< Undetermined error while handling an OBIDMS column directory
                                    	 	 */
#define OBICOLDIR_ACCESS_ERROR    	(12) 	/**< Permission error trying to access an OBIDSM column directory
                                    		 */

#define OBICOL_BAD_ENDIAN_ERROR   	(13) 	/**< The opened data structure does not corresponds
                                    		 *   to the endianness of the platform.
                                    		 */
#define OBICOL_EXIST_ERROR     		(14) 	/**< Trying to create an OBIDMS column with a name
                                    		 *   that corresponds to an existing one
                                    		 */
#define OBICOL_NOT_EXIST_ERROR  	(15) 	/**< Trying to open a non-existing OBIDMS column directory
                                    		 */
#define OBICOL_LONG_NAME_ERROR 	    (16) 	/**< The specified OBIDMS column directory name is too long
                                    		 */
#define OBICOL_MEMORY_ERROR    		(17) 	/**< A memory error occurred during allocation while handling
											 *	 an OBIDMS column directory
                                    	 	 */
#define OBICOL_UNKNOWN_ERROR   		(18) 	/**< Undetermined error while handling an OBIDMS column directory
                                    	 	 */
#define OBICOL_ACCESS_ERROR    		(19) 	/**< Permission error trying to access an OBIDSM column directory
                                    		 */
/**@}*/

#endif /* OBIERRNO_H_ */
